<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\User;
use Illuminate\Http\Request;
use Spatie\Permission\Models\Permission;
use Spatie\Permission\Models\Role;

class ModeratorsController extends Controller
{
    public function __construct()
    {
        $this->middleware(['permission:moderator']);

    }
    public function index()
    {
        $rows = User::whereType('admin')->whereModerator('true')->orderByDesc('id')->get();
        return view('admin.moderators.index', compact('rows'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.moderators.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {

        $this->validate($request, [
            'username' => 'required|unique:users,username',
            'email' => 'required|email|unique:users',
            'password' => 'required|min:6',
        ]);
        $admin = new User();
        $admin['username'] = $request['username'];
        $admin['email'] = $request['email'];
        $admin['mobile'] = $request['mobile'];
        $admin['moderator'] = 'true';
        $admin['password'] = bcrypt($request['password']);
        $admin['status'] = $request['status'];
        $admin['type'] = 'admin';
        $admin->save();

        $role = Role::create(['name' => $admin->email, 'guard_name' => 'web']);
        $permissions = $request['permissions'];
        foreach ($permissions as $permission) {
            $role->givePermissionTo($permission);
        }
        $admin->assignRole($role->name);

        toast('تمت العملية بنجاح', 'success');
        return redirect()->route('moderators.index');

    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $row = User::find($id);
        return view('admin.moderators.edit', compact('row'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'username' => 'required|unique:users,username,' . $id,
            'email' => 'required|email|unique:users,email,' . $id,

        ]);
        $admin = User::find($id);
        $admin['username'] = $request['username'];
        $admin['email'] = $request['email'];
        $admin['mobile'] = $request['mobile'];
        if ($request['password']) $admin['password'] = bcrypt($request['password']);
        $admin['status'] = $request['status'];

        $admin['type'] = 'admin';
        $admin->update();

        $role = Role::where('name',$admin->email)->first();
        $old_permissions = $admin->getAllPermissions();
        foreach ($old_permissions as $old_permission) {
            $role->revokePermissionTo($old_permission->name);
        }

        foreach ($request['permissions'] as $permission) {
            $role->givePermissionTo($permission);
        }

        toast('تمت العملية بنجاح', 'success');
        return redirect()->route('moderators.index');

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        User::destroy($id);
        return redirect()->back()->with('message', 'تم الحذف بنجاح');
    }
}
