<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Http\Resources\OffersResource;
use App\Http\Resources\OrderRescource;
use App\Http\Resources\OrderStatusResource;
use App\Http\Resources\WorkersResource;
use App\Models\CategoriesOffer;
use App\Models\Category;
use App\Models\Coupons;
use App\Models\Notification;
use App\Models\Offer;
use App\Models\Order;
use App\Models\OrderCategory;
use App\Models\OrderImage;
use App\Models\OrderStatus;
use App\Models\Setting;
use App\Models\UserToken;
use App\User;
use Carbon\Carbon;
use Edujugon\PushNotification\PushNotification;
use Illuminate\Http\Request;
use JWTAuth;

class OrdersController extends Controller
{
    public function offerOrder(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }

        $validator = \Validator::make($request->all(), [
            'category_id' => 'required|exists:categories,id',
            'worker_id' => 'required|exists:users,id',
            'offer_id' => 'required|exists:categories_offers,id',
            'days_count' => 'required',
            'date' => 'required',
            'payment_type' => 'required|in:visa,bank',
            'address_id' => 'required|exists:addresses,id',
            'transfer_image' => 'image|required_if:payment_type,bank'
        ]);


        if ($validator->passes()) {


            $selectedCategory = Category::find($request['category_id']);
            $selectedOffer = CategoriesOffer::find($request['offer_id']);


            $order = new Order();
            $order->user_id = $user->id;
            $order->title = $selectedCategory->name['ar'];
            $order->description = $selectedOffer->description['ar'];
            $order->address_id = $request['address_id'];
            $order->date = $request['date'];

            $order->worker_id = $request['worker_id'];
            $order->categoryOffer_id = $request['offer_id'];

            $order->days_count = $request['days_count'];
            $order->status = 'new';
            $order->payment_type = $request['payment_type'];
            $order->code = uniqid();
            $order->save();


            OrderCategory::create([
                'order_id' => $order->id,
                'category_id' => $request['category_id']
            ]);


            $offer = new Offer();
            $offer->order_id = $order->id;
            $offer->worker_id = $request['worker_id'];
            $offer->price = $selectedCategory->price;
            $offer->comment = $selectedCategory->name['ar'];
            $offer->status = 'approve';
            $offer->deliver_price = 0;

            $offer->save();
            $setting = Setting::first();

            if ($request['payment_type'] == 'visa') {
                Order::where('id', $offer->order_id)->update([
                    'offer_id' => $offer->id,
                    'price_offer' => $offer->price,
                    'deliver_price' => $offer->deliver_price,
                    'total_price' => ($offer->price + $offer->deliver_price) + (($offer->price + $offer->deliver_price) * $setting->fee / 100),
                    'worker_id' => $offer->worker_id,
                    'payment_type' => 'visa',
                    'firstPayCheck' => 'true',
                ]);


            } elseif ($request['payment_type'] == 'bank') {


                if ($request->hasFile('transfer_image')) {
                    $filename = time() . '.' . $request['transfer_image']->getClientOriginalExtension();
                    $request['transfer_image']->move(public_path('images/banks'), $filename);
                }


                Order::where('id', $offer->order_id)->update([
                    'offer_id' => $offer->id,
                    'price_offer' => $offer->price,
                    'deliver_price' => $offer->deliver_price,
                    'total_price' => ($offer->price + $offer->deliver_price) + (($offer->price + $offer->deliver_price) * $setting->fee / 100),
                    'status' => 'admin_wait',
                    'worker_id' => $offer->worker_id,
                    'payment_type' => 'bank',
                    'firstPayCheck' => 'false',
                    'transfer_image' => $filename,
                ]);
                $data = new OrderRescource(Order::find($offer->order_id));
                return response()->json(['value' => true, 'data' => $data, 'message' => \Lang::get('data.paymentPostponed')]);

            }


            $data = new OrderRescource($order);
            return response()->json(['value' => true, 'data' => $data]);

        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }
    }


    public function order(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }

        $validator = \Validator::make($request->all(), [
            'categories' => 'required',
            'title' => 'required',
            'description' => 'required',
            'days_count' => 'required',
            'date' => 'required',
            'address_id' => 'required|exists:addresses,id'
        ], [
            'lat.required' => 'Please Open Gps',
            'lng.required' => 'Please Open Gps',
        ]);


        if ($validator->passes()) {
            $order = new Order();
            $order->user_id = $user->id;
            $order->title = $request['title'];
            $order->description = $request['description'];
            $order->address_id = $request['address_id'];
            $order->date = $request['date'];

            $order->days_count = $request['days_count'];
            $order->status = 'new';
            $order->payment_type = $request['payment_type'];
            $order->code = uniqid();
            $order->save();
            if ($request['categories']) {
                foreach (explode(',', $request['categories']) as $category) {
                    OrderCategory::create([
                        'order_id' => $order->id,
                        'category_id' => $category
                    ]);
                }
            }
            $i = 1;
            if ($request['images']) {
                foreach ($request['images'] as $single_image) {
                    $filename = $i . time() . '.' . $single_image->getClientOriginalExtension();
                    $single_image->move(public_path('images/orders'), $filename);
                    OrderImage::create([
                        'order_id' => $order->id,
                        'image' => $filename
                    ]);
                    $i++;

                }
            }


            // notification for workers


            $categories_array = explode(',', $request['categories']);
            $setting = Setting::first();
            $matched_workers = User::where('type', 'worker')->where('status', 'active')->get()->filter(function ($d_worker) use ($categories_array) {
                $worker_categories = $d_worker->worker_categories->pluck('id');
                $result = array_intersect($categories_array, $worker_categories->toArray());
                return count($result) == count($categories_array);
            });


            $workers = $matched_workers->pluck('id');


            foreach ($workers as $worker) {
                $notification = new Notification();
                $notification['user_id'] = $worker;
                $notification['body->ar'] = " لديكم طلب جديد  ";
                $notification['body->en'] = "You have a new Order ";
                $notification['type'] = 'new_order';
                $notification['order_id'] = $order->id;
                $notification->save();
            }

            $tokens = UserToken::whereIn('user_id', $workers)->get();
            $push = new PushNotification('fcm');
            foreach ($tokens as $token) {

                $title = " لديكم طلب جديد  ";
                $body = " لديكم طلب جديد  ";

                if ($token->device_type == 'ios') {
                    $msg = [
                        'data' => [
                            'title_ar' => " لديكم طلب جديد  ",
                            'title_en' => "You have a new Order ",
                            'body_ar' => " لديكم طلب جديد  ",
                            'body_en' => "You have a new Order ",
                            'type' => 'new_order',
                            'sound' => 'default',
                            'title' => $title,
                            'body' => $body,
                            'order_id' => $order->id,
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'notification' => [
                            'title_ar' => " لديكم طلب جديد  ",
                            'title_en' => "You have a new Order ",
                            'body_ar' => " لديكم طلب جديد  ",
                            'body_en' => "You have a new Order ",
                            'type' => 'new_order',
                            'sound' => 'default',
                            'title' => $title,
                            'body' => $body,
                            'order_id' => $order->id,
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                } else {
                    $msg = [
                        'data' => [
                            'title_ar' => " لديكم طلب جديد  ",
                            'title_en' => "You have a new Order ",
                            'body_ar' => " لديكم طلب جديد  ",
                            'body_en' => "You have a new Order ",
                            'type' => 'new_order',
                            'sound' => 'default',
                            'title' => $title,
                            'body' => $body,
                            'order_id' => $order->id,
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                }

            }


            $data = new OrderRescource($order);
            return response()->json(['value' => true, 'data' => $data]);

        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }
    }

    public function search_workers(Request $request)
    {

        $validator = \Validator::make($request->all(), [
            'categories' => 'required',
            'lat' => 'required',
            'lng' => 'required'
        ], [
            'lat.required' => \Lang::get('data.openGPS'),
            'lng.required' => \Lang::get('data.openGPS'),
        ]);
        if ($validator->passes()) {
            $categories_array = explode(',', $request['categories']);


            $lat = $request->lat;
            $lng = $request->lng;


            $matched_workers = User::select(\DB::raw('*, ( 6367 * acos( cos( radians(' . $lat . ') ) * cos( radians( lat ) ) * cos( radians( lng ) - radians(' . $lng . ') ) + sin( radians(' . $lat . ') ) * sin( radians( lat ) ) ) ) AS distance'))
                ->having('distance', '<', 100)
                ->orderBy('distance')->where('type', 'worker')->where('status', 'active')->get()->filter(function ($d_worker) use ($categories_array) {
                    $worker_categories = $d_worker->worker_categories->pluck('id');
                    $result = array_intersect($categories_array, $worker_categories->toArray());
                    return count($result) > 0;
                });
            return WorkersResource::collection($matched_workers)->additional(['value' => true]);


        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }


    }

    public function offer_response(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        $validator = \Validator::make($request->all(), [
            'offer_id' => 'required|exists:offers,id',
            'status' => 'required|in:approve,decline',

        ]);
        if ($validator->passes()) {
            $offer = Offer::find($request['offer_id']);
            $offer['status'] = $request['status'];
            $offer->update();
            if ($request['status'] == 'approve') {
                $setting = Setting::first();

                if ($request['payment_type'] == 'visa') {
                    Order::where('id', $offer->order_id)->update([
                        'offer_id' => $offer->id,
                        'price_offer' => $offer->price,
                        'deliver_price' => $offer->deliver_price,
                        'total_price' => ($offer->price + $offer->deliver_price) + (($offer->price + $offer->deliver_price) * $setting->fee / 100),
                        'status' => 'in_progress',
                        'worker_id' => $offer->worker_id,
                        'payment_type' => 'visa',
                        'firstPayCheck' => 'true',

                    ]);


                    $order = Order::find($offer->order_id);
                    // send notification to worker
                    $notification = new Notification();
                    $notification['user_id'] = $offer->worker_id;
                    $notification['order_id'] = $offer->order_id;
                    $notification['body->ar'] = " تمت الموافقة علي عرضكم علي طلب رقم  $order->code";
                    $notification['body->en'] = " Your offer for order no. $order->code is approved ";
                    $notification['type'] = 'client_accept';
                    $notification->save();
                    $tokens = UserToken::where('user_id', $offer->worker_id)->get();
                    $push = new PushNotification('fcm');
                    foreach ($tokens as $token) {


                        $title = $notification->body['ar'];
                        $body = $notification->body['ar'];

                        if ($token->device_type == 'ios') {
                            $msg = [
                                'data' => [
                                    'title_ar' => $notification['body->ar'],
                                    'title_en' => $notification['body->en'],
                                    'body_ar' => $notification['body->ar'],
                                    'body_en' => $notification['body->en'],
                                    'type' => 'client_accept',
                                    'sound' => 'default',
                                    'title' => $title,
                                    'body' => $body,
                                    'order_id' => $order->id,
                                    'click_action' => 'FCM_PLUGIN_ACTIVITY',
                                ],
                                'notification' => [
                                    'title_ar' => $notification['body->ar'],
                                    'title_en' => $notification['body->en'],
                                    'body_ar' => $notification['body->ar'],
                                    'body_en' => $notification['body->en'],
                                    'type' => 'client_accept',
                                    'sound' => 'default',
                                    'title' => $title,
                                    'body' => $body,
                                    'order_id' => $order->id,
                                    'click_action' => 'FCM_PLUGIN_ACTIVITY',
                                ],
                                'priority' => 'high',
                            ];
                            $push->setMessage($msg)
                                ->setDevicesToken($token->token)
                                ->send();

                        } else {
                            $msg = [
                                'data' => [
                                    'title_ar' => $notification['body->ar'],
                                    'title_en' => $notification['body->en'],
                                    'body_ar' => $notification['body->ar'],
                                    'body_en' => $notification['body->en'],
                                    'type' => 'client_accept',
                                    'sound' => 'default',
                                    'title' => $title,
                                    'body' => $body,
                                    'order_id' => $order->id,
                                    'click_action' => 'FCM_PLUGIN_ACTIVITY',
                                ],
                                'priority' => 'high',
                            ];
                            $push->setMessage($msg)
                                ->setDevicesToken($token->token)
                                ->send();

                        }

                    }


                    $data = new OrderRescource($order);
                    return response()->json(['value' => true, 'data' => $data, 'message' => \Lang::get('data.PaymentSuccess')]);

                } elseif ($request['payment_type'] == 'bank') {


                    if ($request->hasFile('transfer_image')) {
                        $filename = time() . '.' . $request['transfer_image']->getClientOriginalExtension();
                        $request['transfer_image']->move(public_path('images/banks'), $filename);
                    }


                    Order::where('id', $offer->order_id)->update([
                        'offer_id' => $offer->id,
                        'price_offer' => $offer->price,
                        'deliver_price' => $offer->deliver_price,
                        'total_price' => ($offer->price + $offer->deliver_price) + (($offer->price + $offer->deliver_price) * $setting->fee / 100),
                        'status' => 'admin_wait',
                        'worker_id' => $offer->worker_id,
                        'payment_type' => 'bank',
                        'firstPayCheck' => 'false',
                        'transfer_image' => $filename,
                    ]);
                    $data = new OrderRescource(Order::find($offer->order_id));
                    return response()->json(['value' => true, 'data' => $data, 'message' => \Lang::get('data.paymentPostponed')]);

                }

            }
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);

        }
    }

    public function single_order($id)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }

        $order = Order::find($id);
        $data = new OrderRescource($order);
        return response()->json(['value' => true, 'data' => $data]);
    }


    public function client_orders($flag)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        if ($flag == 'in_progress') {
            $rows = Order::whereIn('status', ['in_progress', 'worker_in_way'])->whereUserId($user->id)->orderByDesc('id')->paginate(10);
        } elseif ($flag == 'finish') {
            $rows = Order::whereUserId($user->id)->whereIn('status', ['finish', 'client_finish', 'worker_finish'])->orderByDesc('id')->paginate(10);
        } else {
            $rows = Order::whereUserId($user->id)->whereStatus($flag)->orderByDesc('id')->paginate(10);
        }
        return OrderRescource::collection($rows)->additional(['value' => true, 'code' => 200]);

    }

    public function update_order(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }

        $validator = \Validator::make($request->all(), [

            'city_id' => 'exists:cities,id',
            'order_id' => 'required|exists:orders,id'

        ]);
        if ($validator->passes()) {
            $order = Order::find($request['order_id']);
            $order->title = $request['title'] ? $request['title'] : $order->title;
            $order->description = $request['description'] ? $request['description'] : $order['description'];
            $order->city_id = $request['city_id'] ? $request['city_id'] : $order->city_id;
            $order->lat = $request['lat'] ? $request['lat'] : $order->lat;
            $order->lng = $request['lng'] ? $request['lng'] : $order->lng;
            $order->address = $request['address'] ? $request['address'] : $order->address;
            $order->date = $request['date'] ? $request['date'] : $order->date;
            $order->start_time = $request['start_time'] ? $request['start_time'] : $order->start_time;
            $order->finish_time = $request['finish_time'] ? $request['finish_time'] : $order->finish_time;

            $order->update();

            $i = 1;
            if ($request->images) {
                OrderImage::whereOrderId($order->id)->delete();
                foreach ($request['images'] as $single_image) {
                    $filename = $i . time() . '.' . $single_image->getClientOriginalExtension();
                    $single_image->move(public_path('images/orders'), $filename);
                    OrderImage::create([
                        'order_id' => $order->id,
                        'image' => $filename
                    ]);
                    $i++;

                }
            }
            $data = new OrderRescource($order);
            return response()->json(['value' => true, 'data' => $data]);

        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }


    }

    public function cancel_order($id)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        Order::where('id', $id)->update([
            'status' => 'canceled'
        ]);

        return response()->json(['value' => true, 'data' => \Lang::get('data.order_canceled')]);
    }

    public function delete_order($id)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        Order::destroy($id);

        return response()->json(['value' => true, 'data' => \Lang::get('data.deleted')]);
    }

    public function worker_home()
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $rows = Order::whereStatus('new')->orderByDesc('id')->paginate(10);
        return OrderRescource::collection($rows)->additional(['value' => true, 'code' => 200]);

    }

    public function add_offer(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }

        $validator = \Validator::make($request->all(), [
            'order_id' => 'required|exists:orders,id',
            'price' => 'required',
            'comment' => 'required',
            'deliver_price' => 'required'

        ]);
        if ($validator->passes()) {
            $order = Order::find($request['order_id']);
            Offer::create([
                'worker_id' => $user->id,
                'order_id' => $request['order_id'],
                'price' => $request['price'],
                'comment' => $request['comment'],
                'status' => 'waiting',
                'deliver_price' => $request['deliver_price']
            ]);

            // notification for owner


            // send notification to worker
            $notification = new Notification();
            $notification['user_id'] = $order->user_id;
            $notification['order_id'] = $order->id;
            $notification['body->ar'] = " لديكم عرض طلب لطلب رقم $order->code ";
            $notification['body->en'] = " Your order no. $order->code has a new offer ";
            $notification['type'] = 'offer';
            $notification->save();
            $tokens = UserToken::where('user_id', $order->user_id)->get();
            $push = new PushNotification('fcm');
            foreach ($tokens as $token) {

                $title = $notification->body['ar'];
                $body = $notification->body['ar'];

                if ($token->device_type == 'ios') {
                    $msg = [
                        'data' => [
                            'title_ar' => $notification['body->ar'],
                            'title_en' => $notification['body->en'],
                            'body_ar' => $notification['body->ar'],
                            'body_en' => $notification['body->en'],
                            'type' => 'offer',
                            'sound' => 'default',
                            'title' => $title,
                            'body' => $body,
                            'order_id' => $order->id,
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'notification' => [
                            'title_ar' => $notification['body->ar'],
                            'title_en' => $notification['body->en'],
                            'body_ar' => $notification['body->ar'],
                            'body_en' => $notification['body->en'],
                            'type' => 'offer',
                            'sound' => 'default',
                            'title' => $title,
                            'body' => $body,
                            'order_id' => $order->id,
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                } else {
                    $msg = [
                        'data' => [
                            'title_ar' => $notification['body->ar'],
                            'title_en' => $notification['body->en'],
                            'body_ar' => $notification['body->ar'],
                            'body_en' => $notification['body->en'],
                            'type' => 'offer',
                            'sound' => 'default',
                            'title' => $title,
                            'body' => $body,
                            'order_id' => $order->id,
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                }

            }


            $data = new OrderRescource($order);
            return response()->json(['value' => true, 'data' => $data]);


        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }
    }

    public function single_offer($id)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $offer = Offer::find($id);
        $data = new OffersResource($offer);
        return response()->json(['value' => true, 'data' => $data]);

    }

    public function update_offer(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $validator = \Validator::make($request->all(), [
            'offer_id' => 'required|exists:offers,id',
            'price' => 'required',
            'comment' => 'required',
            'deliver_price' => 'required'

        ]);

        if ($validator->passes()) {
            Offer::where('id', $request['offer_id'])->update([
                'price' => $request['price'],
                'comment' => $request['comment'],
                'deliver_price' => $request['deliver_price'],
            ]);
            $offer = Offer::find($request['offer_id']);
            $data = new OffersResource($offer);
            return response()->json(['value' => true, 'data' => $data]);


        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }


    }

    public function delete_offer($id)
    {
        Offer::destroy($id);
        return response()->json(['value' => true, 'data' => \Lang::get('data.delete_done')]);
    }

    public function worker_orders($flag)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }

        if ($flag == 'waiting') {
            $worker_offers = Offer::where('worker_id', $user->id)->whereStatus('waiting')->pluck('order_id');
            $rows = Order::whereIn('id', $worker_offers)->whereStatus('new')->orderByDesc('id')->paginate(10);
        } elseif ($flag == 'in_progress') {
            $rows = Order::whereIn('status', ['in_progress', 'worker_in_way'])->whereWorkerId($user->id)->orderByDesc('id')->paginate(10);
        } elseif ($flag == 'finish') {
            $rows = Order::whereIn('status', ['finish', 'client_finish', 'worker_finish'])->whereWorkerId($user->id)->orderByDesc('id')->paginate(10);
        } else {
            $rows = Order::where('status', $flag)->whereWorkerId($user->id)->orderByDesc('id')->paginate(10);

        }

        return OrderRescource::collection($rows)->additional(['value' => true, 'code' => 200]);


    }


    public function orderStatus()
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        $rows = OrderStatus::all();
        return OrderStatusResource::collection($rows)->additional([
            'value' => true,
        ]);

    }

    public function change_order_status(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        $validator = \Validator::make($request->all(), [
            'status' => 'required|in:worker_finish,canceled,worker_in_way,client_finish,worker_arrive,paid',
            'order_id' => 'required|exists:orders,id',

        ]);
        if ($validator->passes()) {

            $order = Order::find($request['order_id']);

            if ($request['status'] == 'client_finish') {
                $finish_code = rand(1111, 9999);
                $order->finish_code = $finish_code;


                // send code for worker


                $client_name = $order->user->username;
                // send notification to worker
                $notification = new Notification();
                $notification['user_id'] = $order->worker_id;
                $notification['order_id'] = $order->id;
                $notification['body->ar'] = "قام العميل $client_name بإرسال كود الإنتهاء علي طلب رقم $order->code و كود الإنتهاء هو $finish_code ";
                $notification['body->en'] = "Client $client_name finished order no . $order->code and Finish code is $finish_code";
                $notification['type'] = 'order_finish';
                $notification->save();
                $tokens = UserToken::where('user_id', $order->worker_id)->get();
                $push = new PushNotification('fcm');
                foreach ($tokens as $token) {

                    $title = $notification->body['ar'];
                    $body = $notification->body['ar'];
                    if ($token->device_type == 'ios') {
                        $msg = [
                            'data' => [
                                'title_ar' => $notification['body->ar'],
                                'title_en' => $notification['body->en'],
                                'body_ar' => $notification['body->ar'],
                                'body_en' => $notification['body->en'],
                                'type' => 'order_finish',
                                'sound' => 'default',
                                'title' => $title,
                                'body' => $body,
                                'order_id' => $order->id,
                                'click_action' => 'FCM_PLUGIN_ACTIVITY',
                            ],
                            'notification' => [
                                'title_ar' => $notification['body->ar'],
                                'title_en' => $notification['body->en'],
                                'body_ar' => $notification['body->ar'],
                                'body_en' => $notification['body->en'],
                                'type' => 'order_finish',
                                'sound' => 'default',
                                'title' => $title,
                                'body' => $body,
                                'order_id' => $order->id,
                                'click_action' => 'FCM_PLUGIN_ACTIVITY',
                            ],
                            'priority' => 'high',
                        ];
                        $push->setMessage($msg)
                            ->setDevicesToken($token->token)
                            ->send();

                    } else {
                        $msg = [
                            'data' => [
                                'title_ar' => $notification['body->ar'],
                                'title_en' => $notification['body->en'],
                                'body_ar' => $notification['body->ar'],
                                'body_en' => $notification['body->en'],
                                'type' => 'order_finish',
                                'sound' => 'default',
                                'title' => $notification['body->ar'],
                                'body' => $notification['body->ar'],
                                'order_id' => $order->id,
                                'click_action' => 'FCM_PLUGIN_ACTIVITY',
                            ],
                            'priority' => 'high',
                        ];
                        $push->setMessage($msg)
                            ->setDevicesToken($token->token)
                            ->send();

                    }

                }


            } elseif ($request['status'] == 'worker_finish') {
                if ($order->finish_code == null) {
                    return response()->json(['value' => false, 'msg' => \Lang::get('data.client_finish_first')]);
                } else {

                    $order->status = $request['status'];

                }
            } elseif ($request['status'] == 'worker_in_way') {


                // notification for owner
                $worker_name = $order->worker->username;
                // send notification to worker
                $notification = new Notification();
                $notification['user_id'] = $order->user_id;
                $notification['order_id'] = $order->id;
                $notification['body->ar'] = " الفني $worker_name في طريقة لكم ";
                $notification['body->en'] = "Worker $worker_name is in his way";
                $notification['type'] = 'worker_in_way';
                $notification->save();
                $tokens = UserToken::where('user_id', $order->user_id)->get();
                $push = new PushNotification('fcm');
                foreach ($tokens as $token) {

                    $title = $notification->body['ar'];
                    $body = $notification->body['ar'];
                    if ($token->device_type == 'ios') {
                        $msg = [
                            'data' => [
                                'title_ar' => $notification['body->ar'],
                                'title_en' => $notification['body->en'],
                                'body_ar' => $notification['body->ar'],
                                'body_en' => $notification['body->en'],
                                'type' => 'worker_in_way',
                                'sound' => 'default',
                                'title' => $title,
                                'body' => $body,
                                'order_id' => $order->id,
                                'click_action' => 'FCM_PLUGIN_ACTIVITY',
                            ],
                            'notification' => [
                                'title_ar' => $notification['body->ar'],
                                'title_en' => $notification['body->en'],
                                'body_ar' => $notification['body->ar'],
                                'body_en' => $notification['body->en'],
                                'type' => 'worker_in_way',
                                'sound' => 'default',
                                'title' => $title,
                                'body' => $body,
                                'order_id' => $order->id,
                                'click_action' => 'FCM_PLUGIN_ACTIVITY',
                            ],
                            'priority' => 'high',
                        ];
                        $push->setMessage($msg)
                            ->setDevicesToken($token->token)
                            ->send();

                    } else {
                        $msg = [
                            'data' => [
                                'title_ar' => $notification['body->ar'],
                                'title_en' => $notification['body->en'],
                                'body_ar' => $notification['body->ar'],
                                'body_en' => $notification['body->en'],
                                'type' => 'worker_in_way',
                                'sound' => 'default',
                                'title' => $title,
                                'body' => $body,
                                'order_id' => $order->id,
                                'click_action' => 'FCM_PLUGIN_ACTIVITY',
                            ],
                            'priority' => 'high',
                        ];
                        $push->setMessage($msg)
                            ->setDevicesToken($token->token)
                            ->send();

                    }

                }


                $order->status = $request['status'];
            } elseif ($request['status'] == 'worker_arrive') {

                // هنا هنعمل الدفع المرحلة الثانية

//                worker_arrive

                $order->status = $request['status'];
                $worker_name = $order->worker->username;

                // NOTIFICATION  TO CLIENT TO PAY SECOND MONEY
                $notification = new Notification();
                $notification['user_id'] = $order->user_id;
                $notification['order_id'] = $order->id;
                $notification['body->ar'] = "تم وصول طلبكم وبرجاء دفع الجزء المتبقي من طلبكم ";
                $notification['body->en'] = "Your order has been received, please pay the remaining part of your order";
                $notification['type'] = 'worker_arrive';
                $notification['secondMoney'] = $order->getLevelPaymentAttribute('secondPay');
                $notification['secondPayCheck'] = $order->secondPayCheck;
                $notification->save();
                $tokens = UserToken::where('user_id', $order->user_id)->get();


                $push = new PushNotification('fcm');


                foreach ($tokens as $token) {

                    $title = $notification->body['ar'];
                    $body = $notification->body['ar'];
                    if ($token->device_type == 'ios') {
                        $msg = [
                            'data' => [
                                'title_ar' => $notification['body->ar'],
                                'title_en' => $notification['body->en'],
                                'body_ar' => $notification['body->ar'],
                                'body_en' => $notification['body->en'],
                                'type' => 'worker_arrive',
                                'sound' => 'default',
                                'title' => $title,
                                'body' => $body,
                                'order_id' => $order->id,
                                'secondMoney' => $order->getLevelPaymentAttribute('secondPay'),
                                'secondPayCheck' => $order->secondPayCheck ? $order->secondPayCheck : '',
                                'click_action' => 'FCM_PLUGIN_ACTIVITY',
                            ],
                            'notification' => [
                                'title_ar' => $notification['body->ar'],
                                'title_en' => $notification['body->en'],
                                'body_ar' => $notification['body->ar'],
                                'body_en' => $notification['body->en'],
                                'type' => 'worker_arrive',
                                'sound' => 'default',
                                'title' => $title,
                                'body' => $body,
                                'order_id' => $order->id,
                                'secondMoney' => $order->getLevelPaymentAttribute('secondPay'),
                                'secondPayCheck' => $order->secondPayCheck ? $order->secondPayCheck : '',
                                'click_action' => 'FCM_PLUGIN_ACTIVITY',
                            ],
                            'priority' => 'high',
                        ];
                        $push->setMessage($msg)
                            ->setDevicesToken($token->token)
                            ->send();

                    } else {
                        $msg = [
                            'data' => [
                                'title_ar' => $notification['body->ar'],
                                'title_en' => $notification['body->en'],
                                'body_ar' => $notification['body->ar'],
                                'body_en' => $notification['body->en'],
                                'type' => 'worker_arrive',
                                'sound' => 'default',
                                'title' => $title,
                                'body' => $body,
                                'order_id' => $order->id,
                                'secondMoney' => $order->getLevelPaymentAttribute('secondPay'),
                                'secondPayCheck' => $order->secondPayCheck ? $order->secondPayCheck : '',
                                'click_action' => 'FCM_PLUGIN_ACTIVITY',
                            ],
                            'priority' => 'high',
                        ];
                        $push->setMessage($msg)
                            ->setDevicesToken($token->token)
                            ->send();

                    }

                }


            } elseif ($request['status'] == 'paid') {

                $order->status = 'paid';
                $order->secondPayCheck = 'true';
                $secondPayWorker = $order->getLevelPaymentAttribute('workerSecondPay');


                $setting = Setting::first();
                $worker = User::find($order->worker_id);

                if ($worker->special_commission) {
                    $commission = $worker->special_commission;
                } else {
                    $commission = $setting->single_commission;
                }

                $add_commission = $secondPayWorker - ($secondPayWorker * $commission / 100);

                $worker->wallet -= $add_commission;


                $order['system_money'] = ($secondPayWorker * $commission / 100);


                $notification = new Notification();
                $notification['user_id'] = $order->user_id;
                $notification['order_id'] = $order->id;
                $notification['body->ar'] = " تم دفع مبلغ الطلب   $order->code";
                $notification['body->en'] = " The order amount has been paid $order->code ";
                $notification['type'] = 'paid';
                $notification->save();
                $tokens = UserToken::where('user_id', $order->user_id)->get();
                $push = new PushNotification('fcm');
                foreach ($tokens as $token) {

                    $title = $notification->body['ar'];
                    $body = $notification->body['ar'];

                    if ($token->device_type == 'ios') {
                        $msg = [
                            'data' => [
                                'title_ar' => $notification['body->ar'],
                                'title_en' => $notification['body->en'],
                                'body_ar' => $notification['body->ar'],
                                'body_en' => $notification['body->en'],
                                'type' => 'paid',
                                'sound' => 'default',
                                'title' => $title,
                                'body' => $body,
                                'order_id' => $order->id,
                                'click_action' => 'FCM_PLUGIN_ACTIVITY',
                            ],
                            'notification' => [
                                'title_ar' => $notification['body->ar'],
                                'title_en' => $notification['body->en'],
                                'body_ar' => $notification['body->ar'],
                                'body_en' => $notification['body->en'],
                                'type' => 'paid',
                                'sound' => 'default',
                                'title' => $title,
                                'body' => $body,
                                'order_id' => $order->id,
                                'click_action' => 'FCM_PLUGIN_ACTIVITY',
                            ],
                            'priority' => 'high',
                        ];
                        $push->setMessage($msg)
                            ->setDevicesToken($token->token)
                            ->send();

                    } else {
                        $msg = [
                            'data' => [
                                'title_ar' => $notification['body->ar'],
                                'title_en' => $notification['body->en'],
                                'body_ar' => $notification['body->ar'],
                                'body_en' => $notification['body->en'],
                                'type' => 'paid',
                                'sound' => 'default',
                                'title' => $title,
                                'body' => $body,
                                'order_id' => $order->id,
                                'click_action' => 'FCM_PLUGIN_ACTIVITY',
                            ],
                            'priority' => 'high',
                        ];
                        $push->setMessage($msg)
                            ->setDevicesToken($token->token)
                            ->send();

                    }

                }


            } else {
                $order->status = $request['status'];
            }

            $order->update();


            $data = new OrderRescource($order);

            return response()->json(['value' => true, 'data' => $data]);

        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }
    }


    public function pay_order(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        $validator = \Validator::make(\request()->all(), [
            'order_id' => 'required|exists:orders,id',
            'offer_id' => 'required|exists:offers,id',
            'payment_type' => 'required|in:visa,bank',
            'transfer_image' => 'required_if:payment_method,bank',
            'bank_id' => 'required_if:payment_method,bank|exists:banks,id',
            'coupon' => 'nullable'
        ]);

        if ($validator->passes()) {


            if ($request['coupon']) {

                $code = Coupons::whereCode($request['coupon'])->whereDate('start_date', '<=', Carbon::now()->toDateString())
                    ->whereDate('end_date', '>=', Carbon::now()->toDateString())->where('use_count', '>', 0)->first();

                if (!$code) return response()->json(['value' => false, 'msg' => \Lang::get('data.couponError')]);

            }


            $order = Order::find($request['order_id']);
            $order->coupon = $request['coupon'];
            $order_offer_price = $order->price_offer;
            $order_deliver_price = $order->deliver_price;
            $order_all_price = $order->total_price;
            $worker = User::find($order->worker_id);
            $commission = 0;
            $setting = Setting::first();
            $commission = $setting->single_commission;
            $offer = Offer::find($request['offer_id']);

            $offer->status = 'approve';
            $offer->update();

            if ($request['payment_type'] == 'visa') {


                $setting = Setting::first();
                $offerAndDeliverPrice = round($offer->price + $offer->deliver_price, 2);

                if (isset($code)) {
                    $allPriceAndFee = round($offerAndDeliverPrice + ($offerAndDeliverPrice * $setting->fee / 100), 2);


                    if ($code->discount_type == 'discount') {
                        $discount_amount = $allPriceAndFee * $code->discount_amount / 100;

                    } else {
                        $discount_amount = $code->discount_amount;

                    }

                    $max_discount = $code->max_discount;
                    if ($discount_amount > $max_discount) {

                        $sub_amount = $max_discount;

                    } else {

                        $sub_amount = $discount_amount;

                    }


                    $allPriceAndFee = $allPriceAndFee - $sub_amount;

                } else {
                    $allPriceAndFee = round($offerAndDeliverPrice + ($offerAndDeliverPrice * $setting->fee / 100), 2);

                }

                $firstPay = round($allPriceAndFee * 15 / 100, 2); // Client with additional fee
                $firstPayWorker = round($offerAndDeliverPrice * 15 / 100, 2); // To Worker wallet without additional fee
                $secondPay = $allPriceAndFee - $firstPay;


                Order::where('id', $request->order_id)->update([
                    'offer_id' => $request->offer_id,
                    'price_offer' => $offer->price,
                    'deliver_price' => $offer->deliver_price,
                    'total_price' => $allPriceAndFee,
                    'status' => 'in_progress',
                    'worker_id' => $offer->worker_id,
                    'payment_type' => 'visa',
                    'firstPayCheck' => 'true',
                    'coupon' => $request['coupon']


                ]);


                $order_offer_price = $order->price_offer;
                $order_deliver_price = $order->deliver_price;

                $order_all_price = $order->total_price;


                $worker = User::find($order->worker_id);
                $commission = 0;
                $setting = Setting::first();


                if ($worker->special_commission) {

                    $commission = $worker->special_commission;
                } else {

                    $commission = $setting->single_commission;

                }

                $offer = Offer::find($request['offer_id']);


                $add_commission = $firstPayWorker - ($firstPayWorker * $commission / 100);

                $worker->wallet += $add_commission;


                $additional_fee = $order_all_price - ($order_offer_price + $order_deliver_price); // additional fee

                $order['system_money'] = $additional_fee + ($firstPayWorker * $commission / 100);


                $order = Order::find($offer->order_id);
                // send notification to worker
                $notification = new Notification();
                $notification['user_id'] = $offer->worker_id;
                $notification['order_id'] = $offer->order_id;
                $notification['body->ar'] = " تمت الموافقة علي عرضكم علي طلب رقم  $order->code";
                $notification['body->en'] = " Your offer for order no. $order->code is approved ";
                $notification['type'] = 'client_accept';
                $notification->save();
                $tokens = UserToken::where('user_id', $offer->worker_id)->get();
                $push = new PushNotification('fcm');
                foreach ($tokens as $token) {


                    $title = $notification->body['ar'];
                    $body = $notification->body['ar'];

                    if ($token->device_type == 'ios') {
                        $msg = [
                            'data' => [
                                'title_ar' => $notification['body->ar'],
                                'title_en' => $notification['body->en'],
                                'body_ar' => $notification['body->ar'],
                                'body_en' => $notification['body->en'],
                                'type' => 'client_accept',
                                'sound' => 'default',
                                'title' => $title,
                                'body' => $body,
                                'order_id' => $order->id,
                                'click_action' => 'FCM_PLUGIN_ACTIVITY',
                            ],
                            'notification' => [
                                'title_ar' => $notification['body->ar'],
                                'title_en' => $notification['body->en'],
                                'body_ar' => $notification['body->ar'],
                                'body_en' => $notification['body->en'],
                                'type' => 'client_accept',
                                'sound' => 'default',
                                'title' => $title,
                                'body' => $body,
                                'order_id' => $order->id,
                                'click_action' => 'FCM_PLUGIN_ACTIVITY',
                            ],
                            'priority' => 'high',
                        ];
                        $push->setMessage($msg)
                            ->setDevicesToken($token->token)
                            ->send();

                    } else {
                        $msg = [
                            'data' => [
                                'title_ar' => $notification['body->ar'],
                                'title_en' => $notification['body->en'],
                                'body_ar' => $notification['body->ar'],
                                'body_en' => $notification['body->en'],
                                'type' => 'client_accept',
                                'sound' => 'default',
                                'title' => $title,
                                'body' => $body,
                                'order_id' => $order->id,
                                'click_action' => 'FCM_PLUGIN_ACTIVITY',
                            ],
                            'priority' => 'high',
                        ];
                        $push->setMessage($msg)
                            ->setDevicesToken($token->token)
                            ->send();

                    }

                }


                $data = new OrderRescource($order);
                return response()->json(['value' => true, 'data' => $data, 'message' => \Lang::get('data.PaymentSuccess')]);

            } elseif ($request['payment_type'] == 'bank') {

                if ($request->hasFile('transfer_image')) {
                    $filename = time() . '.' . $request['transfer_image']->getClientOriginalExtension();
                    $request['transfer_image']->move(public_path('images/banks'), $filename);
                }


                if (isset($code)) {
                    $allPriceAndFee = ($offer->price + $offer->deliver_price) + (($offer->price + $offer->deliver_price) * $setting->fee / 100);
                    if ($code->discount_type == 'discount') {
                        $discount_amount = $allPriceAndFee * $code->discount_amount / 100;

                    } else {
                        $discount_amount = $code->discount_amount;

                    }
                    $max_discount = $code->max_discount;
                    if ($discount_amount > $max_discount) {

                        $sub_amount = $max_discount;

                    } else {

                        $sub_amount = $discount_amount;

                    }


                    $allPriceAndFee = $allPriceAndFee - $sub_amount;

                } else {
                    $allPriceAndFee = ($offer->price + $offer->deliver_price) + (($offer->price + $offer->deliver_price) * $setting->fee / 100);

                }


                Order::where('id', $offer->order_id)->update([
                    'offer_id' => $offer->id,
                    'price_offer' => $offer->price,
                    'deliver_price' => $offer->deliver_price,
                    'total_price' => $allPriceAndFee,
                    'status' => 'admin_wait',
                    'worker_id' => $offer->worker_id,
                    'payment_type' => 'bank',
                    'firstPayCheck' => 'false',
                    'transfer_image' => $filename,
                    'bank_id' => $request['bank_id'],
                    'coupon' => $request['coupon']
                ]);


                $data = new OrderRescource($order);
                return response()->json(['value' => true, 'data' => $data, 'message' => \Lang::get('data.paymentPostponed')]);

            }
            $order->update();
            $worker->update();


        } else {
            return response()->json(['value' => true, 'msg' => $validator->errors()->first()]);
        }


    }


    public function secondPayment(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        $validator = \Validator::make($request->all(), [
            'order_id' => 'required|exists:orders,id',
            'payment_type' => 'required|in:visa,bank',
            'bank_id' => 'required_if:payment_type,bank|exists:banks,id',
            'transfer_image' => 'required_if:payment_type,bank'
        ]);


        if ($validator->passes()) {

            $order = Order::find($request['order_id']);


            if ($request['payment_type'] == 'bank') {

                if ($request->hasFile('transfer_image')) {
                    $filename = time() . '.' . $request['transfer_image']->getClientOriginalExtension();
                    $request['transfer_image']->move(public_path('images/banks'), $filename);
                }


                Order::where('id', $request['order_id'])->update([
                    'status' => 'admin_wait',
                    'payment_type' => 'bank',
                    'secondPayCheck' => 'false',
                    'second_transfer_image' => $filename,
                    'second_bank_id' => $request['bank_id']
                ]);


                $data = new OrderRescource($order);
                return response()->json(['value' => true, 'data' => $data, 'message' => \Lang::get('data.paymentPostponed')]);


            } else {

                $secondPayWorker = $order->getLevelPaymentAttribute('workerSecondPay');


                Order::where('id', $request->order_id)->update([

                    'payment_type' => 'visa',
                    'secondPayCheck' => 'true',

                ]);
                $setting = Setting::first();
                $worker = User::find($order->worker_id);

                if ($worker->special_commission) {
                    $commission = $worker->special_commission;
                } else {
                    $commission = $setting->single_commission;

                }

                $add_commission = $secondPayWorker - ($secondPayWorker * $commission / 100);

                $worker->wallet += $add_commission;


                $order['system_money'] = ($secondPayWorker * $commission / 100);


                // send notification to worker
                $notification = new Notification();
                $notification['user_id'] = $order->worker_id;
                $notification['order_id'] = $order->id;
                $notification['body->ar'] = " تم تحويل الجزء المتبقي من الطلب بنجاح الخاص بطلب رقم $order->code";
                $notification['body->en'] = " The remaining part of the request has been successfully transferred to request a number $order->code ";
                $notification['type'] = 'client_accept';
                $notification->save();
                $tokens = UserToken::where('user_id', $order->worker_id)->get();
                $push = new PushNotification('fcm');
                foreach ($tokens as $token) {


                    $title = $notification->body['ar'];
                    $body = $notification->body['ar'];

                    if ($token->device_type == 'ios') {
                        $msg = [
                            'data' => [
                                'title_ar' => $notification['body->ar'],
                                'title_en' => $notification['body->en'],
                                'body_ar' => $notification['body->ar'],
                                'body_en' => $notification['body->en'],
                                'type' => 'client_accept',
                                'sound' => 'default',
                                'title' => $title,
                                'body' => $body,
                                'order_id' => $order->id,
                                'click_action' => 'FCM_PLUGIN_ACTIVITY',
                            ],
                            'notification' => [
                                'title_ar' => $notification['body->ar'],
                                'title_en' => $notification['body->en'],
                                'body_ar' => $notification['body->ar'],
                                'body_en' => $notification['body->en'],
                                'type' => 'client_accept',
                                'sound' => 'default',
                                'title' => $title,
                                'body' => $body,
                                'order_id' => $order->id,
                                'click_action' => 'FCM_PLUGIN_ACTIVITY',
                            ],
                            'priority' => 'high',
                        ];
                        $push->setMessage($msg)
                            ->setDevicesToken($token->token)
                            ->send();

                    } else {
                        $msg = [
                            'data' => [
                                'title_ar' => $notification['body->ar'],
                                'title_en' => $notification['body->en'],
                                'body_ar' => $notification['body->ar'],
                                'body_en' => $notification['body->en'],
                                'type' => 'client_accept',
                                'sound' => 'default',
                                'title' => $title,
                                'body' => $body,
                                'order_id' => $order->id,
                                'click_action' => 'FCM_PLUGIN_ACTIVITY',
                            ],
                            'priority' => 'high',
                        ];
                        $push->setMessage($msg)
                            ->setDevicesToken($token->token)
                            ->send();

                    }

                }


                $data = new OrderRescource($order);
                return response()->json(['value' => true, 'data' => $data, 'message' => \Lang::get('data.PaymentSuccess')]);
            }

        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }


    }


    public function worker_finish_code(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        $validator = \Validator::make($request->all(), [
            'order_id' => 'required|exists:orders,id',
            'code' => 'required'
        ]);
        if ($validator->passes()) {
            $order = Order::find($request['order_id']);
            if ($order->finish_code == $request['code']) {

                $order->status = 'finish';
                $order->update();
                $data = new OrderRescource($order);
                return response()->json(['value' => true, 'data' => $data, 'message' => \Lang::get('data.code_correct')]);


            } else {
                return response()->json(['value' => true, 'data' => \Lang::get('data.code_error')]);

            }

        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);

        }
    }

    public function checkCoupon(Request $request)
    {
        $validator = \Validator::make($request->all(), [
            'code' => 'required'
        ]);
        if ($validator->passes()) {

            $code = Coupons::whereCode($request['code'])->whereDate('start_date', '<=', Carbon::now()->toDateString())
                ->whereDate('end_date', '>=', Carbon::now()->toDateString())->where('use_count', '>', 0)->first();

            if ($code) {
                $data = \Lang::get('data.couponSuccess') . ' ' . $code->discount_amount ;
                return response()->json(['value' => true, 'data' => $data]);
            } else {
                return response()->json(['value' => false, 'msg' => \Lang::get('data.couponError')]);
            }
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }
    }
}
