<?php

namespace App\Http\Resources;

use App\Models\Coupons;
use App\Models\Offer;
use App\Models\OrderStatus;
use App\Models\Setting;
use Illuminate\Http\Resources\Json\JsonResource;
use function Sodium\add;

class OrderRescource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array
     */
    public function toArray($request)
    {
        $setting = Setting::first();
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $offerAndDeliverPrice = 0;
        $firstPay = 0;
        $secondPay = 0;
        if ($this->offer_id) {
            $offer = Offer::find($this->offer_id);
            $setting = Setting::first();
            $offerAndDeliverPrice = (integer)$offer->price + (integer)$offer->deliver_price;
            if ($this->coupon) {

                $code = Coupons::whereCode($this->coupon)->first();


                $allPriceAndFee = round($offerAndDeliverPrice + ($offerAndDeliverPrice * $setting->fee / 100), 2);
                if ($code->discount_type == 'discount'){
                    $discount_amount = $allPriceAndFee * $code->discount_amount / 100;

                }else{
                    $discount_amount = $code->discount_amount;

                }
                $max_discount = $code->max_discount;


                if ($discount_amount > $max_discount) {

                    $sub_amount = $max_discount;

                } else {

                    $sub_amount = $discount_amount;

                }


                $allPriceAndFee = $allPriceAndFee - $sub_amount;

            } else {
                $allPriceAndFee = round($offerAndDeliverPrice + ($offerAndDeliverPrice * $setting->fee / 100), 2);

            }

            $firstPay = $allPriceAndFee * 15 / 100;
            $secondPay = $allPriceAndFee - $firstPay;
        }
        $orderStatus = OrderStatus::where('key', $this->status)->first();
        if ($orderStatus) {
            $statusName = $orderStatus->name[\App::getLocale()];
        } else {
            $statusName = '';
        }


        return [
            'id' => $this->id,
            'title' => $this->title,
            'description' => $this->description,
            'owner_id' => $this->user_id,
            'owner_username' => $this->user ? $this->user->username : '',
            'owner_mobile' => $this->user ? $this->user->mobile : '',
            'owner_email' => $this->user ? $this->user->email : '',
            'owner_image' => $this->user->image ? asset('images/users/' . $this->user->image) : '',
            'user_rate' => getUserRate($this->user_id),
            'worker_id' => $this->worker_id ? (integer)$this->worker_id : 0,
            'worker_username' => $this->worker ? $this->worker->username : '',
            'worker_mobile' => $this->worker ? $this->worker->mobile : '',
            'worker_email' => $this->worker ? $this->worker->email : '',
            'worker_image' => ($this->worker && $this->worker->image) ? asset('images/users/' . $this->worker->image) : '',
            'worker_rate' => $this->worker_id ? getUserRate($this->worker_id) : 0,
            'city_id' => $this->city ? (integer)$this->city->id : 0,
            'city_name' => $this->city ? $this->city->name[$lang] : '',
            'lat' => $this->address_detail ? $this->address_detail->lat : '',
            'lng' => $this->address_detail ? $this->address_detail->lng : '',
            'address' => $this->address_detail ? $this->address_detail->address : '',
            'date' => $this->date ? $this->date : '',
            'days_count' => $this->days_count ? $this->days_count : '',
            'start_time' => $this->start_time ? $this->start_time : '',
            'finish_time' => $this->finish_time ? $this->finish_time : '',
            'price_offer' => $this->price_offer ? $this->price_offer : '',
            'deliver_price' => $this->deliver_price ? $this->deliver_price : '',
            'total_price' => $this->total_price ? $this->total_price : '',
            'additional_fee' => (integer)($offerAndDeliverPrice * $setting->fee / 100),
            'first_pay' => (integer)$firstPay,
            'second_pay' => (integer)$secondPay,
            'categoryOffer_id' => $this->categoryOffer_id ? (integer)$this->categoryOffer_id : 0,
            'payment_type' => $this->payment_type ? $this->payment_type : '',
            'finish_code' => $this->finish_code ? (string)$this->finish_code : '',
            'status' => $this->status ? $this->status : '',
            'statusName' => $statusName,
            'code' => $this->code ? (string)$this->code : '',
            'firstPayCheck' => $this->firstPayCheck ? $this->firstPayCheck : '',
            'secondPayCheck' => $this->secondPayCheck ? $this->secondPayCheck : '',
            'images' => $this->categoryOffer_id ? $this->category_offer_image : OrderImagesResource::collection($this->images),


            'categories' => SubCategoriesResource::collection($this->categories),
            'offers' => OffersResource::collection($this->offers)
        ];
    }
}
