<?php

namespace App\Http\Resources;

use Illuminate\Http\Resources\Json\JsonResource;
use JWTAuth;

class WorkersResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array
     */
    public function toArray($request)
    {
        $lang = \App::getLocale();



        $lat1 = 0;
        $lng1 = 0;


        if ($request->header('Authorization')) {
            if (!$user = JWTAuth::parseToken()->authenticate()) {
                return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
            }



            $lat1 = $user->lat;
            $lng1 = $user->lng;
        }


        $distance = calculateDistance($lat1, $lng1, $this->lat, $this->lng);




        return [
            'id' => $this->id,
            'username' => $this->username ? $this->username : '',
            'mobile' => $this->mobile ? $this->mobile : '',
            'email' => $this->email ? $this->email : '',
            'country_id' => $this->city_id ? (integer)$this->city->country->id : 0,
            'country_name' => $this->city_id ? $this->city->country->name[$lang] : '',
            'city_id' => $this->city_id ? (integer)$this->city_id : 0,
            'city_name' => $this->city_id ? $this->city->name[$lang] : '',
            'code' => $this->code ? (string)$this->code : '',
            'image' => $this->image ? asset('images/users/' . $this->image) : '',
            'experience' => $this->experience ? $this->experience : '',
            'wallet' => $this->wallet ? $this->wallet : '',
            'lat' => $this->lat ? $this->lat : '',
            'lng' => $this->lng ? $this->lng : '',
            'distance'=>$distance,
            'type' => $this->type ? $this->type : '',
            'job' => $this->job,
            'status' => $this->status ? $this->status : '',
            'rate' => getUserRate($this->id),
            'commercial_number' => $this->commercial_number ? $this->commercial_number : '',
            'delivery' => $this->delivery ? $this->delivery : '',
            'category_type' => $this->category_type ? $this->category_type : '',
            'images' => WorkerImagesResource::collection($this->worker_images)
        ];
    }
}
